@@ -1,23 +1,48 @@
-#' Upload a data.frame to Crunch to make a new dataset
+#' Upload data to Crunch to make a new dataset
 #'
-#' This function uses the CSV+JSON import format, which is generally faster and
-#' more effective than \code{\link{newDatasetByColumn}}.
+#' This function creates a new dataset on the Crunch server with either a
+#' data.frame or similar object in your R session, a file, or a URL to a file.
+#' It captures available metadata from your R object and translates it into
+#' Crunch types.
 #'
-#' @param x a data.frame or other rectangular R object
-#' @param name character, the name to give the new Crunch dataset. Default is
-#' the name of the R object passed in \code{x}
-#' @param ... additional arguments passed to \code{ \link{createDataset}}
+#' If you have an SPSS file, it is better specify the file name directly rather
+#' than first reading it into R. Uploading SPSS files directly to Crunch will
+#' preserve metadata that is stripped by the R import, regardless of the library
+#' used to read it into R.
+#'
+#' @param x a `data.frame` or other rectangular R data object, or a string
+#' file name or URL to upload to create a dataset. The file may be a compressed
+#' Zip file containing a single file in CSV or SPSS format.
+#' @param name character name to give the new Crunch dataset. By default the
+#' function uses the name of the R object, or, if passing a file, the file name.
+#' @param ... additional arguments passed to [createDataset()]
 #' @return If successful, an object of class CrunchDataset.
+#' @examples
+#' \dontrun{
+#' ds <- newDataset(mtcars, "cars")
+#' ds <- newDataset("mysurvey.sav")
+#' }
 #' @export
-newDataset <- function (x, name=deparseAndFlatten(substitute(x), max_length = 40), ...) {
+#' @seealso [newDatasetFromFile()]; [newDatasetByColumn()] for an alternate
+#' upload method.
+newDataset <- function (x, name=NULL, ...) {
+    Call <- match.call()
+    if (is.character(x)) {
+        ## Assume we have a file/URL
+        Call[[1]] <- as.name("newDatasetFromFile")
+        return(eval.parent(Call))
+    }
+
     is.2D <- !is.null(dim(x)) && length(dim(x)) %in% 2
     if (!is.2D) {
         halt("Can only make a Crunch dataset from a two-dimensional data ",
             "structure")
     }
 
+    if (is.null(name)) {
+        name <- deparseAndFlatten(substitute(x), max_length = 40)
+    }
     ## TODO: something with paginating the CSV batching if lots of data
-    force(name)
     d <- prepareDataForCrunch(x, name=name, ...)
     ds <- createWithPreparedData(d)
     invisible(ds)
@@ -26,17 +51,17 @@ newDataset <- function (x, name=deparseAndFlatten(substitute(x), max_length = 40
 #' Create an empty dataset
 #'
 #' Use only if you're writing a function to create a Crunch dataset from a
-#' custom data structure. If you have a data.frame, just call
-#' \code{\link{newDataset}} on it.
+#' custom data structure. If you have a `data.frame`, just call
+#' [newDataset()] on it.
 #'
 #' @param name character, the name to give the new Crunch dataset. This is
 #' required.
 #' @param body list correctly formatted metadata definition for a dataset. See
-#' docs.crunch.io.
+#' the [Crunch API documentation](http://docs.crunch.io).
 #' @param ... additional arguments for the POST to create the dataset, such as
 #' "description".
 #' @return An object of class CrunchDataset.
-#' @seealso \code{\link{newDataset}}
+#' @seealso [newDataset()]
 #' @keywords internal
 #' @export
 createDataset <- function (name, body, ...) {
@@ -44,18 +69,17 @@ createDataset <- function (name, body, ...) {
         body <- wrapEntity(name=name, ...)
     }
     dataset_url <- crPOST(sessionURL("datasets"), body=toJSON(body))
-    ds <- entity(datasets()[[dataset_url]])
-    invisible(ds)
+    invisible(loadDataset(dataset_url))
 }
 
 #' Translate a data.frame to Crunch format
 #'
-#' This is called within \code{newDataset(ByCsv)} to extract the Crunch metadata
+#' This is called within `newDataset` to extract the Crunch metadata
 #' from the data and to transform the data to match the extracted metadata. You
 #' can call this directly in order to tailor the data import flow more finely.
 #'
-#' @param data A data.frame or other rectangular R object
-#' @param ... additional arguments passed to \code{ \link{createDataset}}.
+#' @param data A `data.frame` or other rectangular R object
+#' @param ... additional arguments passed to [createDataset].
 #' "name" will be required by the Crunch server but is not required by this
 #' function.
 #' @return A data.frame that is a transformation of \code{data} suitable for
@@ -90,12 +114,15 @@ prepareDataForCrunch <- function (data, ...) {
 
 #' Upload a prepared data.frame with metadata to Crunch
 #'
+#' If you have manually created a Crunch dataset object with [prepareDataForCrunch()]
+#' this function allows you to upload it to the app.
+#'
 #' @param data a data.frame that meets the Crunch API specification, as returned
-#' by \code{\link{prepareDataForCrunch}}, or a character path to a file or URL
+#' by [prepareDataForCrunch()], or a character path to a file or URL
 #' where such data has been written as CSV.
-#' @param metadata list of Crunch metadata that corresponds to \code{data}.
-#' Default is the "metadata" attribute of \code{data}, as returned by
-#' \code{prepareDataForCrunch}, or a character path to a file where such
+#' @param metadata list of Crunch metadata that corresponds to `data`.
+#' Default is the "metadata" attribute of `data`, as returned by
+#' `prepareDataForCrunch`, or a character path to a file where such
 #' metadata has been written as JSON.
 #' @return A CrunchDataset.
 #' @export
@@ -106,15 +133,16 @@ createWithPreparedData <- function (data, metadata=attr(data, "metadata")) {
 #' Persist to disk a prepared data.frame and metadata
 #'
 #' @param data a data.frame that meets the Crunch API specification, as returned
-#' by \code{\link{prepareDataForCrunch}}.
+#' by [prepareDataForCrunch()].
 #' @param metadata list of Crunch metadata that corresponds to \code{data}.
 #' Default is the "metadata" attribute of \code{data}, as returned by
-#' \code{prepareDataForCrunch}.
+#' [prepareDataForCrunch()].
 #' @param file character file path, without extension, to write to.
 #' @return A character vector of length 2: given a value of
-#' \code{file="example"}, it would return c("example.csv.gz", "example.json").
+#' `file="example"`, it would return c("example.csv.gz", "example.json").
 #' The function, of course, is called for its side effects of writing a gzipped
 #' CSV and a JSON file to those locations.
+#' @keywords internal
 #' @export
 writePreparedData <- function (data, metadata=attr(data, "metadata"), file) {
     filenames <- paste(file, c("csv.gz", "json"), sep=".")
@@ -125,14 +153,13 @@ writePreparedData <- function (data, metadata=attr(data, "metadata"), file) {
 
 #' Write CSV to a compressed file
 #'
-#' @param x A data.frame or similar CSV-writeable object
+#' @param x A data.frame or similar CSV-writable object
 #' @param file character destination to write the gzipped CSV to
-#' @param na See \code{\link[utils]{write.csv}}. This just changes the default
+#' @param na See [`utils::write.csv`]. This just changes the default
 #' to a Crunch-friendly empty string.
-#' @param row.names logical: write out row names? See \code{write.csv}. This
-#' just sets a default of \code{FALSE}.
-#' @param ... Additional arguments passed to \code{write.csv}.
-#' @return Whatever \code{write.csv} returns.
+#' @param row.names logical: write out row names? See [`utils::write.csv`].
+#' @param ... Additional arguments passed to `write.csv`.
+#' @return A csv file written to dist
 #' @importFrom utils write.csv
 #' @export
 write.csv.gz <- function (x, file, na="", row.names=FALSE, ...) {
@@ -141,10 +168,6 @@ write.csv.gz <- function (x, file, na="", row.names=FALSE, ...) {
     invisible(write.csv(x, file=gf, na=na, row.names=row.names, ...))
 }
 
-## TODO:
-# * Test these new features
-# * Examples
-
 #' Make a dataset with metadata and a CSV
 #'
 #' This function just takes what you give it and POSTs to Crunch. No
@@ -158,23 +181,15 @@ write.csv.gz <- function (x, file, na="", row.names=FALSE, ...) {
 #' TRUE.
 #' @return On success, a new dataset.
 #' @export
-#' @importFrom jsonlite fromJSON
 #' @keywords internal
 createWithMetadataAndFile <- function (metadata, file, strict=TRUE) {
     ds <- uploadMetadata(metadata)
-    tryCatch({
-        out <- uploadData(ds, file, strict)
-    }, error=function (e) {
-        ## We failed to add the batch successfully, so we don't really have
-        ## a useful dataset. So delete the entity that was created initially.
-        with_consent(delete(ds))
-        stop(e)
-    })
-
+    ds <- uploadData(ds, file, strict, first_batch=TRUE)
     message("Done!")
-    return(out)
+    return(ds)
 }
 
+#' @importFrom jsonlite fromJSON
 uploadMetadata <- function (metadata) {
     message("Uploading metadata")
     if (is.character(metadata)) {
@@ -184,7 +199,7 @@ uploadMetadata <- function (metadata) {
     return(createDataset(body=metadata))
 }
 
-uploadData <- function (dataset, data, strict=TRUE) {
+uploadData <- function (dataset, data, strict=TRUE, first_batch=TRUE) {
     message("Uploading data")
     if (!is.character(data)) {
         ## It's a data.frame. Write it out to a file.
@@ -192,7 +207,7 @@ uploadData <- function (dataset, data, strict=TRUE) {
         write.csv.gz(data, f)
         data <- f
     }
-    return(addBatchFile(dataset, data, savepoint=FALSE, strict=strict))
+    return(addBatchFile(dataset, data, strict=strict, first_batch=TRUE))
 }
 
 #' Wrap variable metadata inside a dataset entity
@@ -201,7 +216,7 @@ uploadData <- function (dataset, data, strict=TRUE) {
 #' @param order a valid "order" payload: list containing either aliases or
 #' list(group, entities)
 #' @param ... dataset entity metadata. "name" is required.
-#' @param return list suitiable for JSONing and POSTing to create a dataset
+#' @param return list suitable for JSONing and POSTing to create a dataset
 #' @export
 #' @keywords internal
 shojifyDatasetMetadata <- function (metadata, order=I(names(metadata)), ...) {
@@ -209,55 +224,51 @@ shojifyDatasetMetadata <- function (metadata, order=I(names(metadata)), ...) {
     return(wrapEntity(..., table=tbl))
 }
 
-#' @rdname newDataset
-#' @export
-newDatasetByCSV <- function (...) {
-    Call <- match.call()
-    Call[[1]] <- as.name("newDataset")
-    warning("newDatasetByCSV is deprecated. Use 'newDataset' (it's the same thing).")
-    ds <- eval.parent(Call)
-    invisible(ds)
-}
-
 #' Upload a data.frame column-by-column to make a new dataset
 #'
 #' Use this version if you have lots of variables, under 1M rows, perhaps
-#' backed by ff or other memory-mapped files, and time to kill.
+#' backed by `ff` or other memory-mapped files, and time to kill. You really
+#' probably want [newDataset()] instead.
 #'
 #' @param x a data.frame or other rectangular R object
 #' @param name character, the name to give the new Crunch dataset. Default is
-#' the name of the R object passed in \code{x}
-#' @param ... additional arguments passed to \code{ \link{createDataset}}
+#' the name of the R object passed in `x`
+#' @param ... additional arguments passed to [createDataset()]
 #' @return If successful, an object of class CrunchDataset.
-#' @seealso \code{\link{newDataset}}
+#' @seealso [newDataset()]
 #' @export
+#' @keywords internal
 newDatasetByColumn <- function (x, name=deparseAndFlatten(substitute(x), max_length = 40), ...) {
     vardefs <- lapply(names(x),
         function (v) toVariable(x[[v]], name=v, alias=v))
     ds <- createDataset(name=name, ...)
     ds <- addVariables(ds, vardefs)
-    saveVersion(ds, "initial import")
+    ds <- saveVersion(ds, "initial import")
     invisible(ds)
 }
 
 #' Upload a file to Crunch to make a new dataset
 #'
-#' Use this import method if you have an SPSS data file. Reading such a file
-#' into R as a data.frame will result in lost metadata. You can just send it
-#' directly to Crunch and let the server process it.
+#' This function allows you to upload a `.csv` or `.sav` file directly to Crunch
+#' without first reading it into R. This is useful both because it preserves SPSS
+#' metadata that is lost when reading `.sav` files into R and because it is more
+#' efficient just to upload the file to the server.
 #'
-#' @param file character, the path to a file to upload. This should either be
-#' a .csv or .sav (SPSS) file.
-#' @param name character, the name to give the new Crunch dataset. Default is
-#' the file name
-#' @param ... additional arguments passed to \code{ \link{createDataset}}
-#' @return On success, an object of class \code{CrunchDataset}.
+#' You no longer need to call this function directly: you can call
+#' [newDataset()] and pass the filename or URL, and it will handle it for you,
+#' thereby saving you eight keystrokes.
+#'
+#' @param file character, the path to a local file to upload, or a URL. This
+#' should either be a `.csv` or `.sav` (SPSS) file
+#' @param name character, the name to give the new Crunch dataset. By default the
+#' name of the dataset will be the filename
+#' @param ... additional arguments passed to [createDataset]
+#' @return On success, an object of class [CrunchDataset]
 #' @export
-newDatasetFromFile <- function (file, name=basename(file), ...) {
-    if (!file.exists(file)) {
-        halt("File not found")
-    }
+#' @seealso [newDataset()]
+#' @keywords internal
+newDatasetFromFile <- function (x, name=basename(x), ...) {
     ds <- createDataset(name=name, ...)
-    ds <- addBatchFile(ds, file, savepoint=FALSE)
+    ds <- addBatchFile(ds, x, first_batch=TRUE)
     invisible(ds)
 }
