@@ -1,8 +1,8 @@
 context("Multitables")
 
 test_that("default name for formula", {
-    expect_identical(formulaRHS(a+b~c+d+rollup(e)), "c + d + rollup(e)")
-    expect_identical(formulaRHS("a+b~c+d+rollup(e)"), "c+d+rollup(e)")
+    expect_identical(RHS_string(a+b~c+d+rollup(e)), "c + d + rollup(e)")
+    expect_identical(RHS_string("a+b~c+d+rollup(e)"), "c+d+rollup(e)")
 })
 
 with_mock_crunch({
